A phylogeny from Bansal et al. 2021
bansal_2021_tree.RdA core gene phylogeny from Bansal et al. 2021 (doi:10.1016/j.ygeno.2021.09.021 ) included for use as an example data set. This is the parsed version of the included "bansal_2021_tree.nwk" file.
bansal_2021_tree.RdA core gene phylogeny from Bansal et al. 2021 (doi:10.1016/j.ygeno.2021.09.021 ) included for use as an example data set. This is the parsed version of the included "bansal_2021_tree.nwk" file.